Module diff

Module diff 

The diff command: field-level structural diff of two dump files.

Structs

DiffOptions
Command line options for the diff command. The default is plain, uncolored output with the default float policy.
DiffOutput
Rendered diff output plus the verdict for the exit code.

Functions

parse_args
Parses the arguments after diff: two paths plus optional flags.
render
Diffs the dump files at the two paths.