Crate tickwise_cli

Crate tickwise_cli 

Library side of the tickwise binary.

The binary is a thin shell over this crate so integration tests can drive the commands directly.

Modules

inspect
The inspect command: metadata and statistics for a recording.

Functions

run
Runs the CLI with the given arguments, excluding the program name, and returns the process exit code.