The diff command: field-level structural diff of two dump files.
Structs
- Diff
Options - Command line options for the diff command. The default is plain, uncolored output with the default float policy.
- Diff
Output - Rendered diff output plus the verdict for the exit code.
Functions
- parse_
args - Parses the arguments after
diff: two paths plus optional flags. - render
- Diffs the dump files at the two paths.